function [XW]= DWTMat(X,NW,lev,conv)

%DWTMat: applies the DWT to each row of matrix X 
%	    
%*******************************************************************
%INPUTS:
% X, 		  matrix of curves, n by p
% NW,             wavelet number (WavBox parameter)
% lev,            number of levels of DWT (WavBox parameter)
% conv,           convolution version (WavBox parameter)   
%
%OUTPUTS:
% XW,             matrix of wavelet coefficients
%
%USAGE:
% [XW]=DWTMat(X,NW,lev,conv);
%
%NOTES:
% This function requires WavBox 4.3b toolbox (copyright Carl Taswell).
% A DWT is applied to each row and coeffs vectors are reversed so that 
%  scaling coeffs are listed first (this is done to be coherent with 
%  function CovCoeffs.m and the DWT2 of WavBox - it may have changed in 
%  later upgrades of WavBox).
% Daubechies wavelets with maximum number NW of vanishing moments are used.
% Recommended convolution version is conv='CPF'
%
%REFERENCE:
% Brown, P.J., Fearn, T. and Vannucci, M. (2001).
% Bayesian Wavelet Regression on Curves with Applications 
% to a Spectroscopic Calibration Problem. 
% Journal of the American Statistical Society, 96, pp.
%
%
%Copyright (c) 1998-2000 Marina Vannucci.
%**********************************************************************

global MAXLEV
global SCALEN

[n, p]=size(X);   %X is n x p and DWT is applied to rows

%---------------DWT 

setwb('OBJTYP','dwt')
setwb('datsiz',[p,1],'deslev',lev,'conver',conv)
setwb('FILCLS','ORTH','FILFAM','DOMP','ANAPAR',NW)
getwb;

[rig,col]=size(SCALEN);
numero=sum(SCALEN(2:rig,1));
XW=ones(n,numero);

for i=1:n
	CoefEmp=dwt(X(i,:)')';
	indice=[numero-SCALEN(rig,1)+1:numero];
	count=SCALEN(rig,1);
	for j=rig-1:-1:2
		indice=[indice indice(count-SCALEN(j+1,1)+1)-SCALEN(j,1): ...
		indice(count-SCALEN(j+1,1)+1)-1];
		count=count+SCALEN(j,1);
	end
	CoefRov=CoefEmp(indice);
	XW(i,:)=CoefRov;
end
