function [X]= IWTMat(XW,NW,lev,conv,p)

%IWTMat: applies the IWT to each row of matrix XW 
%	    
%*******************************************************************
%INPUTS:
% XW, 		  matrix of wavelet coefficients
% NW,             wavelet number (WavBox parameter)
% lev,            number of levels of DWT (WavBox parameter)
% conv,           convolution version (WavBox parameter) 
% p		  original length of data  
%
%OUTPUTS:
% X,              matrix of reconstructed curves
%
%USAGE:
% [X]=IWTMat(XW,NW,lev,conv,p);
%
%NOTES:
% This function requires WavBox 4.3b toolbox (copyright Carl Taswell).
% Coeffs vectors (rows of XW) are reversed so that wavelet coeffs are 
%  listed first and a IWT is applied to each row (see notes of DWTMat.m)
% With non-power-of-two data I need to know what the length (p) of the data
%  was before the DWT was applied.
% Daubechies wavelets with maximum number NW of vanishing moments are used.
% Recommended convolution version is conv='CPF'
%
%REFERENCE:
% Brown, P.J., Fearn, T. and Vannucci, M. (2001).
% Bayesian Wavelet Regression on Curves with Applications 
% to a Spectroscopic Calibration Problem. 
% Journal of the American Statistical Society, 96, pp.
%
%
%Copyright (c) 1998-2000 Marina Vannucci.
%**********************************************************************

global MAXLEV
global SCALEN

[n]=size(XW,1);  %X will be n x p. IDWT is applied to rows

%---------------IWT

setwb('OBJTYP','dwt')
setwb('datsiz',[p,1],'deslev',lev,'conver',conv)
setwb('FILCLS','ORTH','FILFAM','DOMP','ANAPAR',NW)
getwb;

%----- coeffs are rotated back (DWTMat has rotated them)

[rig,col]=size(SCALEN);
numero=sum(SCALEN(2:rig,1));
scala=rot90(rot90(SCALEN(:,1)));
X=ones(n,p);
for i=1:n
	CoefEmp=XW(i,:);
	indice=[numero-scala(rig-1)+1:numero];
	count=scala(rig-1);
	for j=rig-2:-1:1
	indice(count-scala(j+1)+1)-scala(j);
		indice=[indice indice(count-scala(j+1)+1)-scala(j): ...
		indice(count-scala(j+1)+1)-1];
		count=count+scala(j);
	end
	CoefRov=CoefEmp(indice);
	X(i,:)=idwt(CoefRov')';	
end
