function [UniSt,ProbSt, GammaSt, storeAD, storeS]= ... 
metro_wav(gamprec,probprec,X,Y,k,delta,w,Hg,nPar,pPar);

%metro_wav: Metropolis - Selection prior with non-diagonal cov. matrix Hg
%************************************************************************
%INPUTS:
% gamprec,        initial binary vector.
% probprec,	  log-relative posterior probability of gamprec
% X,              independent variables, n by p
% Y,              response matrix, n by q
% k,delta,        hyperparameters of Inverse Wishart prior
% w,              hyperparameters of prior on latent binary vector
% Hg,		  var-cov matrix of normal prior on regression coefficients
% nPar,           number of iterations
% pPar,           probabitity of Addition/Deletion
%
%OUTPUTS:
% ProbSt,	  log-relative posterior probabilities
%                 of visited vectors
% GammaSt,        cell with positions of 1's in visited vectors
% storeAD,storeS, iteration numbers of accepted additions/deletions (AD)
%                 and swaps (S)
%
%USAGE:
% [ProbSt, GammaSt, storeAD, storeS]= metro_wav(...
% gamprec,probprec,X,Y,k,delta,w,Hg,nPar,pPar);
%
%NOTES:
% Called by bvsme_wav
% Functions called: gofg_wav
% An adding move is forced with empty model
% A delete move is forced with full model
% Designed for a non-diagonal prior (Hg full var-cov matrix).
% This prior does not allow fast QRdelete/insert updating.
%
%REFERENCE:
% Brown, P.J., Fearn, T. and Vannucci, M. (2001).
% Bayesian Wavelet Regression on Curves with Applications 
% to a Spectroscopic Calibration Problem. 
% Journal of the American Statistical Society, 96, pp.
% 
%     
%Copyright (c) 1998-2000 Marina Vannucci.
%************************************************************************

[nOss p]=size(X);
[q]=size(Y,2);
storeAD=[];
storeS=[];
GammaSt=cell(nPar,1);
ProbSt=zeros(1,nPar);
UniSt=zeros(1,nPar);

for i=1:nPar
	flag=0;
	gamnew=gamprec;
	poszeros=find(gamprec==0);
	if length(poszeros)==p		       % Forced to add variable
		chi='AD';
		choice=ceil(rand(1)*p);
		gamnew(choice)=1;
		[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);		
	elseif 	isempty(poszeros)              % Forced to delete variable
		chi='AD';
		choice=ceil(rand(1)*p);
		gamnew(choice)=0;
		[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);
	else			
		x=rand(1);
		if x<pPar

%-------------------Adding/Deleting
			chi='AD';
			choice=ceil(rand(1)*p);
			if gamnew(choice)==0
				gamnew(choice)=1;	
				[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);
			else
				gamnew(choice)=0;
				[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);

			end
		else

%-------------------Swapping
			chi='S';
			poszeros=find(gamprec==0);
			posones=find(gamprec==1);
			choice1=ceil(rand(1)*length(poszeros));
			choice2=ceil(rand(1)*length(posones));
			elem=posones(choice2);
			gamnew(elem)=0;
			[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);
               	 	elem=poszeros(choice1);  
			gamnew(elem)=1;
			[probnew] = gofg_wav(gamnew,X,Y,k,delta,w,Hg);
		end
	end	
	move=min(0, (probnew-probprec) );
	if move==0
		eval(['store',chi,'=[store',chi,' i];'])
                probprec=probnew;
                gamprec=gamnew;   
                ProbSt(i)=probnew;     
                GammaSt{i}=num2str(find(gamnew));
		UniSt(i)=length(find(gamnew));
	else if (rand(1) < exp(move))
			eval(['store',chi,'=[store',chi,' i];'])
			probprec=probnew;
			gamprec=gamnew;
			ProbSt(i)=probnew;
			GammaSt{i}=num2str(find(gamnew));		
			UniSt(i)=length(find(gamnew));
		else
			ProbSt(i)=probprec; 
			GammaSt{i}=num2str(find(gamprec));
			UniSt(i)=length(find(gamprec));
		end
	end
end

