function [UniO,GammaO,logProbO,PostGam]=probordf(Uni,logProb, Gamma)

%probordf: Bayesian Variable Selection
%          Normalized posterior probs and 
% 	   ordering of distinct visited vectors according
%          to probability
%***********************************************************************
%INPUTS:
% Uni,			number of ones of visited models
% logProb,              log-relative post probs of visited models
% Gamma,		matrix or cell of distinct visited models
%
%OUTPUTS:
% UniO,			number of ones
% GammaO,               matrix or cell of distinct visited vectors
%			ordered according to PostGam
% logProbO,             log-relative post probs of visited vectors
%			(ordered)
% PostGam,		normalized posterior probs of visited vectors
%			(ordered)
%
%USAGE:
% [UniO,GammaO,logProbO,PostGam]=probordf(Uni,logProb, Gamma)
%
%Copyright (c) 2000 Marina Vannucci.
%**********************************************************************

%----------------------- normalized posterior probs
media=mean(logProb);
PostGam=exp(logProb-media);
den=sum(PostGam);
PostGam=PostGam/den;

%------------------ Ordering of rows of Gamma according to PostGam
%		    (descending order)

[PostGam ordine]=sort(PostGam);
ordine=rot90(ordine);
PostGam=rot90(PostGam);
switch class(Gamma)
	case 'cell'
		GammaO=Gamma(ordine);
		UniO=Uni(ordine);
	otherwise	
		GammaO=Gamma(ordine,:);
		UniO=[];
end
logProbO=logProb(ordine);
