function [Unew,Gnew, Pnew]=replichef(U,G, P);

%replichef: Bayesian Variable Selection
%          Search for replicates
%***********************************************************************
%INPUTS:
% U,		number of ones
% G,            matrix or cell of visited models 
% P,            vector of log-relative post probs of visited models
%
%OUTPUTS:
% Unew,		number of ones
% Gnew,         matrix G without replicates
% Pnew,         log-relative post probs of vectors in Gnew
%
%USAGE:
% [Unew,Gnew, Pnew]=replichef(U,G, P);
%
%NOTE:
% May be slow with very large matrices --> use cell format
%
%Copyright (c) 2000 Marina Vannucci.
%**********************************************************************

Pnew=[];
Unew=[];
switch class(G)
	case 'sparse'
		GG=full(G);
		flag='y'; 
		% unique does not work with sparse matrices
		Gnew=[];
	case 'cell'
		flag='n';
		Gnew=cell(0);
	otherwise
		flag='n';
		Gnew=[];
end
		
cerca=unique(U);
for i=1:length(cerca)
	ind=find(U==cerca(i));
	switch class(G)
		case 'sparse'
			[GGnew,I,J]=unique(GG(ind,:),'rows');
		case 'cell'
			[GGnew,I,J]=unique(G(ind));
		otherwise
			[GGnew,I,J]=unique(G(ind,:),'rows');               
	end	
	Gnew=cat(1,Gnew,GGnew);
	Pnew=[Pnew P(ind(I))];
	Unew=[Unew U(ind(I))];
end
if flag=='y' 
	Gnew=sparse(Gnew);
else
end
